searchData={"items":[{"type":"module","title":"Jsonb","doc":"A module for building Ecto queries with JSONB columns.\n\nThis module provides a macro `json_query/4` to generate dynamic where clauses\nfor JSONB columns in an Ecto query.","ref":"Jsonb.html"},{"type":"macro","title":"Jsonb.json_query/4","doc":"Builds a dynamic where clause for JSONB columns in an Ecto query.","ref":"Jsonb.html#json_query/4"},{"type":"macro","title":"Parameters - Jsonb.json_query/4","doc":"- qry: The initial query.\n  - col: The JSONB column to query.\n  - params: A keyword list of key-value pairs to match against the JSONB column.\n  - opts: A keyword list of options. Supports `:where_type`, which can be `:where` or `:or_where`. Defaults to `:where`.","ref":"Jsonb.html#json_query/4-parameters"},{"type":"macro","title":"Examples - Jsonb.json_query/4","doc":"iex> import Ecto.Query\n    iex> query = from(p in Post)\n    iex> json_query(query, :metadata, [title: \"Elixir\", author: \"José\"], where_type: :where)\n    # Ecto query with JSONB where clauses","ref":"Jsonb.html#json_query/4-examples"},{"type":"task","title":"mix add","doc":"","ref":"Mix.Tasks.Add.html"},{"type":"function","title":"Mix.Tasks.Add.run/1","doc":"","ref":"Mix.Tasks.Add.html#run/1"},{"type":"module","title":"Phial","doc":"","ref":"Phial.html"},{"type":"module","title":"Provider","doc":"A module for setting up common Ecto query imports and basic CRUD operations.\n\nThis module provides a macro `__using__/1` to include the necessary imports and basic CRUD operations for working with Ecto queries.","ref":"Provider.html"},{"type":"macro","title":"Provider.__using__/1","doc":"Sets up common imports and basic CRUD operations for modules using `Provider`.\n\nThis macro imports `Ecto.Query` and defines basic CRUD functions: `get/3`, `insert/2`, `update/2`, and `delete/2`.","ref":"Provider.html#__using__/1"},{"type":"macro","title":"Examples - Provider.__using__/1","doc":"defmodule MyRepo do\n      use Provider\n      alias MyApp.Repo\n\n      def get_all_users do\n        get(User)\n      end\n\n      def create_user(attrs) do\n        insert(%User{}, attrs)\n      end\n\n      def update_user(user, attrs) do\n        update(user, attrs)\n      end\n\n      def delete_user(user) do\n        delete(user)\n      end\n    end","ref":"Provider.html#__using__/1-examples"},{"type":"module","title":"Responses","doc":"A module providing wrappers for common HTTP responses in Plug applications.\n\nThis module includes functions to send JSON, HTML, text, file responses, and more.\nIt also provides utilities for handling Ecto changeset errors and redirecting requests.","ref":"Responses.html"},{"type":"macro","title":"Responses.__using__/1","doc":"Sets up common imports for modules using `Responses`.\n\nThis macro imports `Plug.Conn` and the current module for easy access to response helpers.","ref":"Responses.html#__using__/1"},{"type":"macro","title":"Examples - Responses.__using__/1","doc":"defmodule MyRouter do\n      use Plug.Router\n      use Responses\n\n      plug :match\n      plug :dispatch\n\n      get \"/\" do\n        conn |> json(:ok, %{hello: \"world\"})\n      end\n    end","ref":"Responses.html#__using__/1-examples"},{"type":"function","title":"Responses.changeset_params/1","doc":"Converts string keys in params to atoms.","ref":"Responses.html#changeset_params/1"},{"type":"function","title":"Parameters - Responses.changeset_params/1","doc":"- params: A map with string keys.","ref":"Responses.html#changeset_params/1-parameters"},{"type":"function","title":"Examples - Responses.changeset_params/1","doc":"changeset_params(%{\"name\" => \"John\"})\n    # => %{name: \"John\"}","ref":"Responses.html#changeset_params/1-examples"},{"type":"function","title":"Responses.download/3","doc":"Sends a file download response.","ref":"Responses.html#download/3"},{"type":"function","title":"Parameters - Responses.download/3","doc":"- conn: HTTP connection to send the response to.\n  - path: File path for the file response.\n  - opts: Keyword list of options. Supports `:resp_headers` to add response headers.","ref":"Responses.html#download/3-parameters"},{"type":"function","title":"Examples - Responses.download/3","doc":"conn |> download(:ok, \"/path/to/file\")\n    conn |> download(:ok, \"/path/to/file\", resp_headers: %{\"x-foo\" => \"bar\"})","ref":"Responses.html#download/3-examples"},{"type":"function","title":"Responses.file/3","doc":"Sends a file response.","ref":"Responses.html#file/3"},{"type":"function","title":"Parameters - Responses.file/3","doc":"- conn: HTTP connection to send the response to.\n  - path: File path for the file response.\n  - opts: Keyword list of options. Supports `:resp_headers` to add response headers.","ref":"Responses.html#file/3-parameters"},{"type":"function","title":"Examples - Responses.file/3","doc":"conn |> file(:ok, \"/path/to/file\")\n    conn |> file(:ok, \"/path/to/file\", resp_headers: %{\"x-foo\" => \"bar\"})","ref":"Responses.html#file/3-examples"},{"type":"function","title":"Responses.html/4","doc":"Sends an HTML response.","ref":"Responses.html#html/4"},{"type":"function","title":"Parameters - Responses.html/4","doc":"- conn: HTTP connection to send the response to.\n  - status: Atom or number that represents the HTTP response code.\n  - data: HTML string set as the response body.\n  - opts: Keyword list of options. Supports `:resp_headers` to add response headers.","ref":"Responses.html#html/4-parameters"},{"type":"function","title":"Examples - Responses.html/4","doc":"conn |> html(:ok, \" Hello World \")\n    conn |> html(:ok, \" Hello World \", resp_headers: %{\"x-foo\" => \"bar\"})","ref":"Responses.html#html/4-examples"},{"type":"function","title":"Responses.json/4","doc":"Sends a JSON response.","ref":"Responses.html#json/4"},{"type":"function","title":"Parameters - Responses.json/4","doc":"- conn: HTTP connection to send the response to.\n  - status: Atom or number that represents the HTTP response code.\n  - data: Struct to be encoded to JSON as the response body.\n  - opts: Keyword list of options. Supports `:resp_headers` to add response headers.","ref":"Responses.html#json/4-parameters"},{"type":"function","title":"Examples - Responses.json/4","doc":"conn |> json(:ok, %{hello: \"World\"})\n    conn |> json(:ok, %{hello: \"World\"}, resp_headers: %{\"x-foo\" => \"bar\"})","ref":"Responses.html#json/4-examples"},{"type":"function","title":"Responses.parse_errors/1","doc":"Parses errors from an Ecto changeset or a given error map/string.","ref":"Responses.html#parse_errors/1"},{"type":"function","title":"Parameters - Responses.parse_errors/1","doc":"- changeset: An Ecto changeset.\n  - errors: An error map or string.","ref":"Responses.html#parse_errors/1-parameters"},{"type":"function","title":"Examples - Responses.parse_errors/1","doc":"parse_errors(%Ecto.Changeset{errors: [name: {\"can't be blank\", []}]})\n    # => %{name: \"can't be blank\"}\n\n    parse_errors(\"An error occurred\")\n    # => %{error: \"An error occurred\"}","ref":"Responses.html#parse_errors/1-examples"},{"type":"function","title":"Responses.redirect/3","doc":"Redirects the request.","ref":"Responses.html#redirect/3"},{"type":"function","title":"Parameters - Responses.redirect/3","doc":"- conn: HTTP connection to redirect.\n  - status: Atom or number that represents the HTTP response code.\n  - url: String representing the URL/URI destination.","ref":"Responses.html#redirect/3-parameters"},{"type":"function","title":"Examples - Responses.redirect/3","doc":"conn |> redirect(\"http://example.com/\")\n    conn |> redirect(301, \"http://example.com/\")","ref":"Responses.html#redirect/3-examples"},{"type":"function","title":"Responses.status/3","doc":"Sends a status-only response.","ref":"Responses.html#status/3"},{"type":"function","title":"Parameters - Responses.status/3","doc":"- conn: HTTP connection to send the response to.\n  - status: Atom or number that represents the HTTP response code.\n  - opts: Keyword list of options. Supports `:resp_headers` to add response headers.","ref":"Responses.html#status/3-parameters"},{"type":"function","title":"Example - Responses.status/3","doc":"conn |> status(:ok)","ref":"Responses.html#status/3-example"},{"type":"function","title":"Responses.text/4","doc":"Sends a text response.","ref":"Responses.html#text/4"},{"type":"function","title":"Parameters - Responses.text/4","doc":"- conn: HTTP connection to send the response to.\n  - status: Atom or number that represents the HTTP response code.\n  - data: Text string set as the response body.\n  - opts: Keyword list of options. Supports `:resp_headers` to add response headers.","ref":"Responses.html#text/4-parameters"},{"type":"function","title":"Examples - Responses.text/4","doc":"conn |> text(:ok, \"Hello World!\")\n    conn |> text(:ok, \"Hello World!\", resp_headers: %{\"x-foo\" => \"bar\"})","ref":"Responses.html#text/4-examples"},{"type":"module","title":"Router","doc":"A module for defining common Plug router configurations.\n\nThis module provides a macro `__using__/1` to include common router settings,\nsuch as required imports, plugs, and necessary configurations for handling requests.","ref":"Router.html"},{"type":"macro","title":"Router.__using__/1","doc":"A macro to set up common configurations for Plug routers.\n\nThis macro includes required imports, setups for parsers, and uses necessary modules\nlike `Plug.Router` and `Responses`.","ref":"Router.html#__using__/1"},{"type":"macro","title":"Examples - Router.__using__/1","doc":"defmodule MyRouter do\n      use Router\n\n      plug :match\n      plug :dispatch\n\n      get \"/\" do\n        send_resp(conn, 200, \"Welcome\")\n      end\n\n      match _ do\n        send_resp(conn, 404, \"Not Found\")\n      end\n    end","ref":"Router.html#__using__/1-examples"},{"type":"module","title":"Schema","doc":"A module for defining common Ecto schema configurations.\n\nThis module provides a macro `__using__/1` to include common schema settings,\nsuch as primary key type, foreign key type, and necessary imports.","ref":"Schema.html"},{"type":"macro","title":"Schema.__using__/1","doc":"A macro to set up common configurations for Ecto schemas.\n\nThis macro sets the primary key to use binary IDs, imports necessary Ecto modules,\nand sets the default foreign key type to binary ID.","ref":"Schema.html#__using__/1"},{"type":"macro","title":"Examples - Schema.__using__/1","doc":"defmodule MySchema do\n      use Schema\n\n      schema \"my_table\" do\n        field :name, :string\n        # additional fields\n      end\n\n      def changeset(struct, params \\ %{}) do\n        struct\n        |> cast(params, [:name])\n        |> validate_required([:name])\n      end\n    end","ref":"Schema.html#__using__/1-examples"},{"type":"extras","title":"Elixir Utilities","doc":"# Elixir Utilities\n\nThis repository contains several utility modules for use with Elixir, particularly focused on Ecto and Plug-based applications. Below are detailed explanations and examples for each module.","ref":"readme.html"},{"type":"extras","title":"Modules - Elixir Utilities","doc":"1. [Jsonb](#jsonb)\n2. [Schema](#schema)\n3. [Router](#router)\n4. [Responses](#responses)\n5. [Provider](#provider)\n\n---","ref":"readme.html#modules"},{"type":"extras","title":"Jsonb - Elixir Utilities","doc":"A module for building Ecto queries with JSONB columns.\n\n#### Example\n\n```elixir\nimport Ecto.Query\nquery = from(p in Post)\njson_query(query, :metadata, [title: \"Elixir\", author: \"José\"], where_type: :where)\n# Ecto query with JSONB where clauses\n```\n\n--- \n\n##Schema\nA module for defining common Ecto schema configurations.\n\n#### Example\n\n```elixir\ndefmodule MySchema do\n  use Schema\n\n  schema \"my_table\" do\n    field :name, :string\n    # additional fields\n  end\n\n  def changeset(struct, params \\\\ %{}) do\n    struct\n    |> cast(params, [:name])\n    |> validate_required([:name])\n  end\nend\n```","ref":"readme.html#jsonb"},{"type":"extras","title":"Router - Elixir Utilities","doc":"A module for defining common Plug router configurations.\n\n#### Example\n\n```elixir\ndefmodule MyRouter do\n  use Router\n\n  plug :match\n  plug :dispatch\n\n  get \"/\" do\n    send_resp(conn, 200, \"Welcome\")\n  end\n\n  match _ do\n    send_resp(conn, 404, \"Not Found\")\n  end\nend\n```","ref":"readme.html#router"},{"type":"extras","title":"Responses - Elixir Utilities","doc":"A module providing wrappers for common HTTP responses in Plug applications.\n\n#### Example\n\n```elixir\n# Sending a JSON response\nconn |> json(:ok, %{hello: \"World\"})\nconn |> json(:ok, %{hello: \"World\"}, resp_headers: %{\"x-foo\" => \"bar\"})\n\n# Sending an HTML response\nconn |> html(:ok, \" Hello World \")\nconn |> html(:ok, \" Hello World \", resp_headers: %{\"x-foo\" => \"bar\"})\n\n# Sending a text response\nconn |> text(:ok, \"Hello World!\")\nconn |> text(:ok, \"Hello World!\", resp_headers: %{\"x-foo\" => \"bar\"})\n\n# Sending a file response\nconn |> file(:ok, \"/path/to/file\")\nconn |> file(:ok, \"/path/to/file\", resp_headers: %{\"x-foo\" => \"bar\"})\n\n# Sending a file download response\nconn |> download(:ok, \"/path/to/file\")\nconn |> download(:ok, \"/path/to/file\", resp_headers: %{\"x-foo\" => \"bar\"})\n\n# Sending a status-only response\nconn |> status(:ok)\n\n# Redirecting the request\nconn |> redirect(\"http://example.com/\")\nconn |> redirect(301, \"http://example.com/\")\n\n# Converting string keys in params to atoms\nchangeset_params(%{\"name\" => \"John\"})\n# => %{name: \"John\"}\n\n# Parsing errors from an Ecto changeset or a given error map/string\nparse_errors(%Ecto.Changeset{errors: [name: {\"can't be blank\", []}]})\n# => %{name: \"can't be blank\"}\n\nparse_errors(\"An error occurred\")\n# => %{error: \"An error occurred\"}\n\n```","ref":"readme.html#responses"},{"type":"extras","title":"Provider - Elixir Utilities","doc":"A module for setting up common Ecto query imports and basic CRUD operations.\n\n#### Example\n\n```elixir\ndefmodule MyRepo do\n  use Provider\n  alias MyApp.Repo\n\n  def get_all_users do\n    get(User)\n  end\n\n  def create_user(attrs) do\n    insert(%User{}, attrs)\n  end\n\n  def update_user(user, attrs) do\n    update(user, attrs)\n  end\n\n  def delete_user(user) do\n    delete(user)\n  end\nend\n```","ref":"readme.html#provider"},{"type":"extras","title":"License - Elixir Utilities","doc":"This project is licensed under the MIT License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}